# -*- coding: utf-8 -*-
# scsamba.dbus.proxy.sambaBackend: DBUS proxy for system-config-samba
# backend
# Copyright © 2008 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See then
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# Authors:
# Nils Philippsen <nphilipp@redhat.com>

from scsamba.dbus import dbus_service_name, dbus_service_path

from slip.dbus import polkit

class SambaBackend (object):
    def __init__ (self, bus):
        self.bus = bus
        self.dbus_service_path = "/".join ((dbus_service_path, "Backend"))
        self.dbus_object = bus.get_object (dbus_service_name, self.dbus_service_path)

    @polkit.enable_proxy
    def isSambaRunning (self):
        return self.dbus_object.isSambaRunning (dbus_interface = "org.fedoraproject.Config.Samba.Backend")

    @polkit.enable_proxy
    def startSamba (self):
        return self.dbus_object.startSamba (dbus_interface = "org.fedoraproject.Config.Samba.Backend")

    @polkit.enable_proxy
    def restartSamba (self):
        return self.dbus_object.restartSamba (dbus_interface = "org.fedoraproject.Config.Samba.Backend")

    @polkit.enable_proxy
    def readSmbConf (self):
        return self.dbus_object.readSmbConf (dbus_interface = "org.fedoraproject.Config.Samba.Backend")

    @polkit.enable_proxy
    def writeSmbConf (self, contents):
        return self.dbus_object.writeSmbConf (contents, dbus_interface = "org.fedoraproject.Config.Samba.Backend")

class SambaUserData (object):
    def __init__ (self, bus):
        self.bus = bus
        self.dbus_service_path = "/".join ((dbus_service_path, "UserData"))
        self.dbus_object = bus.get_object (dbus_service_name, self.dbus_service_path)

    @polkit.enable_proxy
    def getPasswdFile (self):
        return self.dbus_object.getPasswdFile (dbus_interface = "org.fedoraproject.Config.Samba.UserData")

    @polkit.enable_proxy
    def getUsersFile (self):
        return self.dbus_object.getUsersFile (dbus_interface = "org.fedoraproject.Config.Samba.UserData")

    @polkit.enable_proxy
    def getUserDict (self):
        return self.dbus_object.getUserDict (dbus_interface = "org.fedoraproject.Config.Samba.UserData")

    @polkit.enable_proxy
    def writeSmbUsersFile (self):
        return self.dbus_object.writeSmbUsersFile (dbus_interface = "org.fedoraproject.Config.Samba.UserData")

    @polkit.enable_proxy
    def addUser (self, unix_name, windows_name, password):
        return self.dbus_object.addUser (unix_name, windows_name, password, dbus_interface = "org.fedoraproject.Config.Samba.UserData")

    @polkit.enable_proxy
    def changePassword (self, unix_name, password):
        return self.dbus_object.changePassword (unix_name, password, dbus_interface = "org.fedoraproject.Config.Samba.UserData")

    @polkit.enable_proxy
    def changeWindowsUserName (self, unix_name, windows_name):
        return self.dbus_object.changeWindowsUserName (unix_name, windows_name, dbus_interface = "org.fedoraproject.Config.Samba.UserData")

    @polkit.enable_proxy
    def deleteUser (self, name):
        return self.dbus_object.deleteUser (name, dbus_interface = "org.fedoraproject.Config.Samba.UserData")

    @polkit.enable_proxy
    def userExists (self, user):
        return self.dbus_object.userExists (user, dbus_interface = "org.fedoraproject.Config.Samba.UserData")
